@@ -9,35 +9,31 @@ use modphonon
 use modtest
 implicit none
 ! local variables
-integer nb,ik,iq,i,j
+integer ik,iq,i,j
 integer i1,i2,i3,iw
-integer lwork,info
 real(8) wmin,wmax,wd,dw
 real(8) wlog,wrms,lambda,tc
 real(8) v(3),t1
 ! allocatable arrays
-real(8), allocatable :: wq(:,:),wp(:),gq(:,:),a2fp(:)
-real(8), allocatable :: w(:),a2f(:),rwork(:)
+real(8), allocatable :: wq(:,:),gq(:,:)
+real(8), allocatable :: wp(:),a2fp(:),w(:),a2f(:)
 complex(8), allocatable :: dynq(:,:,:),dynr(:,:,:)
 complex(8), allocatable :: dynp(:,:),ev(:,:),b(:,:)
 complex(8), allocatable :: a2fmq(:,:,:),a2fmr(:,:,:),a2fmp(:,:)
-complex(8), allocatable :: work(:)
 ! initialise universal variables
 call init0
 call init1
 call init2
-nb=3*natmtot
-allocate(wq(nb,nqpt),wp(nb),gq(nb,nqpt),a2fp(nb))
-allocate(w(nwplot),a2f(nwplot),rwork(3*nb))
-allocate(dynq(nb,nb,nqpt))
-allocate(dynr(nb,nb,nqptnr))
-allocate(dynp(nb,nb))
-allocate(ev(nb,nb),b(nb,nb))
-allocate(a2fmq(nb,nb,nqpt))
-allocate(a2fmr(nb,nb,nqptnr))
-allocate(a2fmp(nb,nb))
-lwork=2*nb
-allocate(work(lwork))
+allocate(wq(nbph,nqpt),gq(nbph,nqpt))
+allocate(wp(nbph),a2fp(nbph))
+allocate(w(nwplot),a2f(nwplot))
+allocate(dynq(nbph,nbph,nqpt))
+allocate(dynr(nbph,nbph,nqptnr))
+allocate(dynp(nbph,nbph))
+allocate(ev(nbph,nbph),b(nbph,nbph))
+allocate(a2fmq(nbph,nbph,nqpt))
+allocate(a2fmr(nbph,nbph,nqptnr))
+allocate(a2fmp(nbph,nbph))
 ! get the eigenvalues and occupancies from file
 do ik=1,nkpt
   call getevalsv(vkl(:,ik),evalsv(:,ik))
@@ -55,21 +51,22 @@ call dynqtor(dynq,dynr)
 call readgamma(gq)
 ! loop over phonon q-points
 do iq=1,nqpt
-! diagonalise the dynamical matrix
-  call dyndiag(dynq(:,:,iq),wq(:,iq),ev)
+! find the eigenvalues and eigenvectors of the dynamical matrix
+  call dynev(dynq(:,:,iq),wq(:,iq),ev)
 ! construct a complex matrix from the phonon eigenvectors such that its
 ! eigenvalues squared are the phonon linewidths divided by the frequency
-  do i=1,nb
+  do i=1,nbph
     if (wq(i,iq).gt.1.d-8) then
       t1=sqrt(abs(gq(i,iq)/wq(i,iq)))
     else
       t1=0.d0
     end if
-    do j=1,nb
+    do j=1,nbph
       b(i,j)=t1*conjg(ev(j,i))
     end do
   end do
-  call zgemm('N','N',nb,nb,nb,zone,ev,nb,b,nb,zzero,a2fmq(:,:,iq),nb)
+  call zgemm('N','N',nbph,nbph,nbph,zone,ev,nbph,b,nbph,zzero,a2fmq(:,:,iq), &
+   nbph)
 end do
 ! Fourier transform the matrices to real-space
 call dynqtor(a2fmq,a2fmr)
@@ -78,7 +75,7 @@ wmin=0.d0
 wmax=0.d0
 do iq=1,nqpt
   wmin=min(wmin,wq(1,iq))
-  wmax=max(wmax,wq(nb,iq))
+  wmax=max(wmax,wq(nbph,iq))
 end do
 wmax=wmax+(wmax-wmin)*0.1d0
 wmin=wmin-(wmax-wmin)*0.1d0
@@ -98,15 +95,16 @@ do i1=0,ngrkf-1
       v(3)=dble(i3)/dble(ngrkf)
 ! compute the dynamical matrix at this particular q-point
       call dynrtoq(v,dynr,dynp)
-! find the phonon frequencies
-      call dyndiag(dynp,wp,ev)
+! find the phonon eigenvalues and eigenvectors
+      call dynev(dynp,wp,ev)
 ! compute the alpha^2F matrix at this particular q-point
       call dynrtoq(v,a2fmr,a2fmp)
-! diagonlise the alpha^2F matrix
-      call zheev('N','U',nb,a2fmp,nb,a2fp,work,lwork,rwork,info)
+! diagonalise the alpha^2F matrix simultaneously with the dynamical matrix
+! (thanks to Matthieu Verstraete and Ryotaro Arita for correcting this)
+      call dynevs(ev,a2fmp,a2fp)
 ! square the eigenvalues to recover the linewidths divided by the frequency
       a2fp(:)=a2fp(:)**2
-      do i=1,nb
+      do i=1,nbph
         t1=(wp(i)-wmin)/dw+1.d0
         iw=nint(t1)
         if ((iw.ge.1).and.(iw.le.nwplot)) then
@@ -161,8 +159,8 @@ write(*,'(" written to MCMILLAN.OUT")')
 call writetest(251,'Electron-phonon coupling constant, lambda',tol=5.d-2, &
  rv=lambda)
 deallocate(wq,wp,gq,a2fp,w,a2f)
-deallocate(rwork,dynq,dynr,dynp,ev,b)
-deallocate(a2fmq,a2fmr,a2fmp,work)
+deallocate(dynq,dynr,dynp,ev,b)
+deallocate(a2fmq,a2fmr,a2fmp)
 return
 end subroutine
 
