@@ -33,13 +33,11 @@ allocate(zfmt(lmmaxvr,nrmtmax),gzfmt(lmmaxvr,nrmtmax,3))
 ! make complex copy of the density
 do ias=1,natmtot
   is=idxis(ias)
-  do ir=1,nrmt(is)
-    call rtozflm(lmaxvr,rhomt(:,ir,ias),zrhomt(:,ir,ias))
-  end do
+  call rtozfmt(nrmt(is),nrmtinr(is),1,rhomt(:,:,ias),1,zrhomt(:,:,ias))
 end do
 zrhoir(:)=rhoir(:)
 ! compute the gradient of the density
-call gradzf(nrmt,spnrmax,spr,vgc,nrmtmax,zrhomt,zrhoir,grhomt,grhoir)
+call gradzf(zrhomt,zrhoir,grhomt,grhoir)
 !--------------------------------------------------------------!
 !     Hellmann-Feynman force derivative for displaced atom     !
 !--------------------------------------------------------------!
@@ -54,18 +52,18 @@ zrhoir(:)=0.d0
 ! compute the gradient of the nuclear potential
 call potnucl(ptnucl,nr,spr(:,isph),spzn(isph),vn)
 do ir=1,nr
+  zfmt(:,ir)=0.d0
   zfmt(1,ir)=vn(ir)/y00
-  zfmt(2:4,ir)=0.d0
 end do
-call gradzfmt(1,nr,spr(:,isph),lmmaxvr,nrmtmax,zfmt,gzfmt)
+call gradzfmt(nr,nrmtinr(isph),spr(:,isph),zfmt,nrmtmax,gzfmt)
 ! compute the q-dependent nuclear Coulomb potential derivative
 zvclmt(:,:,:)=0.d0
 do ir=1,nr
   zvclmt(2:4,ir,iasph)=gzfmt(2:4,ir,ipph)
 end do
 tphdyn=.true.
-call zpotcoul(nrmt,spnrmax,spr,igq0,gqc,jlgqr,ylmgq,sfacgq,zrhoir,nrmtmax, &
- zvclmt,zvclir,zrho0)
+call zpotcoul(nrmt,nrmtinr,spnrmax,spr,igq0,gqc,jlgqr,ylmgq,sfacgq,zrhoir, &
+ nrmtmax,zvclmt,zvclir,zrho0)
 zfmt(:,:)=zvnmt(:,:)
 ! multiply with density derivative and integrate
 zsum=0.d0
@@ -84,8 +82,8 @@ zvclmt(:,:,:)=0.d0
 do ir=1,nr
   zvclmt(2:4,ir,iasph)=gzfmt(2:4,ir,ipph)
 end do
-call zpotcoul(nrmt,spnrmax,spr,1,gc,jlgr,ylmg,sfacg,zrhoir,nrmtmax,zvclmt, &
- zvclir,zrho0)
+call zpotcoul(nrmt,nrmtinr,spnrmax,spr,1,gc,jlgr,ylmg,sfacg,zrhoir,nrmtmax, &
+ zvclmt,zvclir,zrho0)
 tphdyn=.false.
 ! multiply with density gradient and integrate
 zsum=0.d0
@@ -101,7 +99,7 @@ end do
 dyn(ipph,iasph)=dyn(ipph,iasph)-zsum
 ! nuclear-nuclear term
 zvclmt(:,:,iasph)=zvnmt(:,:)-zfmt(:,:)
-call gradzf(nrmt,spnrmax,spr,vgc,nrmtmax,zvclmt,zvclir,gvclmt,gvclir)
+call gradzf(zvclmt,zvclir,gvclmt,gvclir)
 do ias=1,natmtot
   is=idxis(ias)
   z1=spzn(is)*gvclmt(1,irfhf(is),ias,ipph)*y00
@@ -113,16 +111,15 @@ end do
 do ias=1,natmtot
   is=idxis(ias)
   nr=nrmt(is)
+  nri=nrmtinr(is)
 ! remove the gradient part of the Coulomb potential for displaced muffin-tin
   if (ias.eq.iasph) then
-    do ir=1,nr
-      call rtozflm(lmaxvr,vclmt(:,ir,iasph),zfmt(:,ir))
-    end do
-    call gradzfmt(lmaxvr,nr,spr(:,isph),lmmaxvr,nrmtmax,zfmt,gzfmt)
+    call rtozfmt(nr,nri,1,vclmt(:,:,iasph),1,zfmt)
+    call gradzfmt(nr,nri,spr(:,isph),zfmt,nrmtmax,gzfmt)
     dvclmt(:,1:nr,ias)=dvclmt(:,1:nr,ias)+gzfmt(:,1:nr,ipph)
   end if
 ! compute the gradient of the Coulomb potential derivative at the nucleus
-  call gradzfmt(1,nr,spr(:,is),lmmaxvr,nrmtmax,dvclmt(:,:,ias),gzfmt)
+  call gradzfmt(nr,nri,spr(:,is),dvclmt(:,:,ias),nrmtmax,gzfmt)
   do i=1,3
     if ((ias.eq.iasph).and.(i.eq.ipph)) cycle
     dyn(i,ias)=spzn(is)*gzfmt(1,irfhf(is),i)*y00
@@ -150,15 +147,13 @@ if (tfibs) then
       dyn(i,ias)=dyn(i,ias)-z1
     end do
 ! convert Kohn-Sham potential to complex spherical harmonics
-    do ir=1,nr
-      call rtozflm(lmaxvr,vsmt(:,ir,ias),zfmt(:,ir))
-    end do
+    call rtozfmt(nr,nri,1,vsmt(:,:,ias),1,zfmt)
 ! remove the gradient part from the density derivative for displaced muffin-tin
     if (ias.eq.iasph) then
       drhomt(:,1:nr,ias)=drhomt(:,1:nr,ias)+grhomt(:,1:nr,ias,ipph)
     end if
 ! compute the gradient of the density derivative
-    call gradzfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,drhomt(:,:,ias),gzfmt)
+    call gradzfmt(nr,nri,spr(:,is),drhomt(:,:,ias),nrmtmax,gzfmt)
     do i=1,3
       z1=zfmtinp(.true.,nr,nri,spr(:,is),zfmt,gzfmt(:,:,i))
       dyn(i,ias)=dyn(i,ias)-z1
