@@ -16,16 +16,16 @@ real(8) vn(nrmtmax)
 complex(8), allocatable :: zfmt(:,:),gzfmt(:,:,:)
 nr=nrmt(isph)
 ! solve the complex Poisson's equation in the muffin-tins
-call genzvclmt(nrmt,spnrmax,spr,nrmtmax,drhomt,dvclmt)
+call genzvclmt(nrmt,nrmtinr,spnrmax,spr,nrmtmax,drhomt,dvclmt)
 ! compute the monopole potential for effective nuclear charge
 call potnucl(ptnucl,nr,spr(:,isph),spzn(isph),vn)
 ! calculate the gradient of the monopole potential
-allocate(zfmt(4,nrmtmax),gzfmt(4,nrmtmax,3))
+allocate(zfmt(lmmaxvr,nrmtmax),gzfmt(lmmaxvr,nrmtmax,3))
 do ir=1,nr
+  zfmt(:,ir)=0.d0
   zfmt(1,ir)=vn(ir)/y00
-  zfmt(2:4,ir)=0.d0
 end do
-call gradzfmt(1,nr,spr(:,isph),4,nrmtmax,zfmt,gzfmt)
+call gradzfmt(nr,nrmtinr(isph),spr(:,isph),zfmt,nrmtmax,gzfmt)
 ! subtract gradient component corresponding to the phonon polarisation
 do ir=1,nr
   dvclmt(2:4,ir,iasph)=dvclmt(2:4,ir,iasph)-gzfmt(2:4,ir,ipph)
@@ -37,8 +37,8 @@ if (iqph.eq.iq0) then
 else
   igq0=0
 end if
-call zpotcoul(nrmt,spnrmax,spr,igq0,gqc,jlgqr,ylmgq,sfacgq,drhoir,nrmtmax, &
- dvclmt,dvclir,zrho0)
+call zpotcoul(nrmt,nrmtinr,spnrmax,spr,igq0,gqc,jlgqr,ylmgq,sfacgq,drhoir, &
+ nrmtmax,dvclmt,dvclir,zrho0)
 return
 end subroutine
 
