@@ -58,11 +58,11 @@ do is=1,nspecies
 ! generate the core wavefunction
                 call wavefcr(.false.,lradstp,is,ia,ist,m1,nrcmtmax,wfcr1)
 ! calculate the complex overlap density
-                zfmt(:,1:nrc)=conjg(wfcr1(:,1:nrc,1))*wfcr2(:,1:nrc,1) &
-                 +conjg(wfcr1(:,1:nrc,2))*wfcr2(:,1:nrc,2)
+                call zfmtmul2(nrc,nrci,wfcr1(:,:,1),wfcr1(:,:,2),wfcr2(:,:,1), &
+                 wfcr2(:,:,2),zfmt)
                 call zfsht(nrc,nrci,zfmt,zrhomt)
 ! calculate the Coulomb potential
-                call zpotclmt(lmaxvr,nrc,rcmt(:,is),lmmaxvr,zrhomt,zvclmt)
+                call zpotclmt(nrc,nrci,rcmt(:,is),zrhomt,zvclmt)
                 z1=zfmtinp(.true.,nrc,nrci,rcmt(:,is),zrhomt,zvclmt)
                 engyx=engyx-0.5d0*dble(z1)
               end do
