@@ -15,7 +15,7 @@ complex(8), intent(in) :: apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv)
 complex(8), intent(in) :: evecfv(nmatmax,nstfv,nspnfv)
 complex(8), intent(in) :: evecsv(nstsv,nstsv)
 integer, intent(in) :: ld
-complex(8), intent(out) :: dmat(ld,ld,nspinor,nspinor,nstsv)
+complex(8), intent(out) :: dmat(ld,nspinor,ld,nspinor,nstsv)
 ! local variables
 integer ist,ispn,jspn,is,ia
 integer nrc,nrci,nrc0,irc0,irc
@@ -108,7 +108,7 @@ do j=1,nstsv
             call fderiv(-2,nrc0,rcmt(irc0,is),fr1(irc0),gr(irc0))
             t1=gr(nrc)
             call fderiv(-2,nrc0,rcmt(irc0,is),fr2(irc0),gr(irc0))
-            dmat(lm1,lm2,ispn,jspn,j)=cmplx(t1,gr(nrc),8)
+            dmat(lm1,ispn,lm2,jspn,j)=cmplx(t1,gr(nrc),8)
           end do
         end do
       end do
