@@ -28,8 +28,7 @@ real(8), intent(in) :: dcdg2(lmmaxvr,nrmtmax)
 ! local variables
 integer nr,nri,i
 ! allocatable arrays
-real(8), allocatable :: rfmt1(:,:),rfmt2(:,:)
-real(8), allocatable :: grfmt(:,:,:)
+real(8), allocatable :: rfmt1(:,:),rfmt2(:,:),grfmt(:,:,:)
 allocate(rfmt1(lmmaxvr,nrmtmax),rfmt2(lmmaxvr,nrmtmax))
 allocate(grfmt(lmmaxvr,nrmtmax,3))
 nr=nrmt(is)
@@ -38,13 +37,13 @@ nri=nrmtinr(is)
 !     exchange     !
 !------------------!
 ! convert dxdg2 to spherical harmonics
-call rfsht(nr,nri,dxdg2,rfmt1)
+call rfsht(nr,nri,1,dxdg2,1,rfmt1)
 ! compute grad dxdg2
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 ! (grad dxdg2).(grad rho) in spherical coordinates
 rfmt1(:,1:nr)=0.d0
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),rfmt2)
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,rfmt2)
   rfmt1(:,1:nr)=rfmt1(:,1:nr)+rfmt2(:,1:nr)*gvrho(:,1:nr,i)
 end do
 vx(:,1:nr)=vx(:,1:nr)-2.d0*(rfmt1(:,1:nr)+dxdg2(:,1:nr)*g2rho(:,1:nr))
@@ -52,13 +51,13 @@ vx(:,1:nr)=vx(:,1:nr)-2.d0*(rfmt1(:,1:nr)+dxdg2(:,1:nr)*g2rho(:,1:nr))
 !     correlation     !
 !---------------------!
 ! convert dcdg2 to spherical harmonics
-call rfsht(nr,nri,dcdg2,rfmt1)
+call rfsht(nr,nri,1,dcdg2,1,rfmt1)
 ! compute grad dcdg2
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 ! (grad dcdg2).(grad rho) in spherical coordinates
 rfmt1(:,1:nr)=0.d0
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),rfmt2)
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,rfmt2)
   rfmt1(:,1:nr)=rfmt1(:,1:nr)+rfmt2(:,1:nr)*gvrho(:,1:nr,i)
 end do
 vc(:,1:nr)=vc(:,1:nr)-2.d0*(rfmt1(:,1:nr)+dcdg2(:,1:nr)*g2rho(:,1:nr))
