@@ -64,45 +64,45 @@ nri=nrmtinr(is)
 !     rho up     !
 !----------------!
 ! convert rhoup to spherical harmonics
-call rfsht(nr,nri,rhoup,rfmt1)
+call rfsht(nr,nri,1,rhoup,1,rfmt1)
 ! grad rhoup in spherical coordinates
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),gvup(:,:,i))
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,gvup(:,:,i))
 end do
 ! |grad rhoup|
 gup(:,1:nr)=sqrt(gvup(:,1:nr,1)**2+gvup(:,1:nr,2)**2+gvup(:,1:nr,3)**2)
 ! grad^2 rhoup in spherical coordinates
-call grad2rfmt(lmaxvr,nr,spr(:,is),lmmaxvr,rfmt1,rfmt2)
-call rbsht(nr,nri,rfmt2,g2up)
+call grad2rfmt(nr,nri,spr(:,is),rfmt1,rfmt2)
+call rbsht(nr,nri,1,rfmt2,1,g2up)
 ! (grad rhoup).(grad |grad rhoup|)
-call rfsht(nr,nri,gup,rfmt1)
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call rfsht(nr,nri,1,gup,1,rfmt1)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 g3up(:,1:nr)=0.d0
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),rfmt1)
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,rfmt1)
   g3up(:,1:nr)=g3up(:,1:nr)+gvup(:,1:nr,i)*rfmt1(:,1:nr)
 end do
 !------------------!
 !     rho down     !
 !------------------!
 ! convert rhodn to spherical harmonics
-call rfsht(nr,nri,rhodn,rfmt1)
+call rfsht(nr,nri,1,rhodn,1,rfmt1)
 ! grad rhodn in spherical coordinates
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),gvdn(:,:,i))
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,gvdn(:,:,i))
 end do
 gdn(:,1:nr)=sqrt(gvdn(:,1:nr,1)**2+gvdn(:,1:nr,2)**2+gvdn(:,1:nr,3)**2)
 ! grad^2 rhodn in spherical coordinates
-call grad2rfmt(lmaxvr,nr,spr(:,is),lmmaxvr,rfmt1,rfmt2)
-call rbsht(nr,nri,rfmt2,g2dn)
+call grad2rfmt(nr,nri,spr(:,is),rfmt1,rfmt2)
+call rbsht(nr,nri,1,rfmt2,1,g2dn)
 ! (grad rhodn).(grad |grad rhodn|)
-call rfsht(nr,nri,gdn,rfmt1)
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call rfsht(nr,nri,1,gdn,1,rfmt1)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 g3dn(:,1:nr)=0.d0
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),rfmt1)
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,rfmt1)
   g3dn(:,1:nr)=g3dn(:,1:nr)+gvdn(:,1:nr,i)*rfmt1(:,1:nr)
 end do
 !-------------!
@@ -113,11 +113,11 @@ grho(:,1:nr)=sqrt((gvup(:,1:nr,1)+gvdn(:,1:nr,1))**2 &
                  +(gvup(:,1:nr,2)+gvdn(:,1:nr,2))**2 &
                  +(gvup(:,1:nr,3)+gvdn(:,1:nr,3))**2)
 ! (grad rho).(grad |grad rho|)
-call rfsht(nr,nri,grho,rfmt1)
-call gradrfmt(lmaxvr,nr,spr(:,is),lmmaxvr,nrmtmax,rfmt1,grfmt)
+call rfsht(nr,nri,1,grho,1,rfmt1)
+call gradrfmt(nr,nri,spr(:,is),rfmt1,nrmtmax,grfmt)
 g3rho(:,1:nr)=0.d0
 do i=1,3
-  call rbsht(nr,nri,grfmt(:,:,i),rfmt1)
+  call rbsht(nr,nri,1,grfmt(:,:,i),1,rfmt1)
   g3rho(:,1:nr)=g3rho(:,1:nr)+(gvup(:,1:nr,i)+gvdn(:,1:nr,i))*rfmt1(:,1:nr)
 end do
 deallocate(rfmt1,rfmt2,grfmt,gvup,gvdn)
