@@ -12,8 +12,8 @@
 !!
 !! You should have received a copy of the GNU Lesser General Public License
 !! along with this program; if not, write to the Free Software
-!! Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-!! 02111-1307, USA.
+!! Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+!! 02110-1301, USA.
 !!
 !! $Id: libxc.f90 3550 2007-11-19 14:32:49Z marques $
 !-------------------------------------------------------------------
@@ -51,7 +51,8 @@ module xc_f90_lib_m
     XC_FAMILY_MGGA = 4, &
     XC_FAMILY_LCA = 8, &
     XC_FAMILY_OEP = 16, &
-    XC_FAMILY_HYB_GGA = 32
+    XC_FAMILY_HYB_GGA = 32, &
+    XC_FAMILY_HYB_MGGA = 64
 
   integer, parameter :: &
     XC_UNPOLARIZED = 1, & ! Spin unpolarized
@@ -80,9 +81,10 @@ module xc_f90_lib_m
     XC_FLAGS_STABLE = 512, &
     XC_FLAGS_DEVELOPMENT = 1024
 
-  ! This value was redefined as XC_GGA_X_LB, we define it here to keep
-  ! compatibility.
+  ! These are old names keep for compatibility, and that should disappear soon
   integer, parameter :: XC_GGA_XC_LB = 160
+  integer, parameter :: XC_GGA_K_ABSR1 = 506
+  integer, parameter :: XC_GGA_K_ABSR2 = 507
 
   !----------------------------------------------------------------
   interface
@@ -127,6 +129,15 @@ module xc_f90_lib_m
       character(len=*), intent(out) :: s ! the string that is output
     end subroutine xc_f90_info_refs
 
+    subroutine xc_f90_functional_get_name(func_number, func_string)
+      integer, intent(in) :: func_number
+      character(len=256), intent(out) :: func_string
+    end subroutine xc_f90_functional_get_name
+
+    integer function xc_f90_functional_get_number(func_string)
+      character(len=*), intent(in) :: func_string
+    end function xc_f90_functional_get_number
+
     integer function xc_f90_family_from_id(id)
       use xc_f90_types_m
       integer, intent(in) :: id
@@ -247,7 +258,8 @@ module xc_f90_lib_m
   ! GGAs
   !----------------------------------------------------------------
   interface
-    subroutine xc_f90_gga(p, np, rho, sigma, zk, vrho, vsigma, v2rho2, v2rhosigma, v2sigma2)
+    subroutine xc_f90_gga(p, np, rho, sigma, zk, vrho, vsigma, &
+        v2rho2, v2rhosigma, v2sigma2, v3rho3, v3rho2sigma, v3rhosigma2, v3sigma3)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: p
       integer, intent(in) :: np
@@ -259,6 +271,10 @@ module xc_f90_lib_m
       real(xc_f90_kind), intent(out) :: v2rho2
       real(xc_f90_kind), intent(out) :: v2rhosigma
       real(xc_f90_kind), intent(out) :: v2sigma2
+      real(xc_f90_kind), intent(out) :: v3rho3
+      real(xc_f90_kind), intent(out) :: v3rho2sigma
+      real(xc_f90_kind), intent(out) :: v3rhosigma2
+      real(xc_f90_kind), intent(out) :: v3sigma3
     end subroutine xc_f90_gga
 
     subroutine xc_f90_gga_exc(p, np, rho, sigma, zk)
@@ -301,6 +317,18 @@ module xc_f90_lib_m
       real(xc_f90_kind), intent(out) :: v2rhosigma
       real(xc_f90_kind), intent(out) :: v2sigma2
     end subroutine xc_f90_gga_fxc
+
+    subroutine xc_f90_gga_kxc(p, np, rho, sigma, v3rho3, v3rho2sigma, v3rhosigma2, v3sigma3)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      integer, intent(in) :: np
+      real(xc_f90_kind), intent(in) :: rho
+      real(xc_f90_kind), intent(in) :: sigma
+      real(xc_f90_kind), intent(out) :: v3rho3
+      real(xc_f90_kind), intent(out) :: v3rho2sigma
+      real(xc_f90_kind), intent(out) :: v3rhosigma2
+      real(xc_f90_kind), intent(out) :: v3sigma3
+    end subroutine xc_f90_gga_kxc
   end interface
 
   !----------------------------------------------------------------
@@ -330,16 +358,6 @@ module xc_f90_lib_m
   end interface
 
 
-  !----------------------------------------------------------------
-  interface
-    subroutine xc_f90_hyb_exx_coef(p, coef)
-      use xc_f90_types_m
-      type(xc_f90_pointer_t), intent(in) :: p
-      real(xc_f90_kind), intent(out) :: coef
-    end subroutine xc_f90_hyb_exx_coef
-  end interface
-
-
   !----------------------------------------------------------------
   interface
     subroutine xc_f90_gga_x_wpbeh_set_par(p, omega)
@@ -360,11 +378,43 @@ module xc_f90_lib_m
 
   !----------------------------------------------------------------
   interface
-    subroutine xc_f90_hyb_gga_xc_hse_set_par(p, omega)
+    subroutine xc_f90_gga_ak13_get_asymptotic(homo, asymp)
+      use xc_f90_types_m
+      real(xc_f90_kind), intent(in) :: homo
+      real(xc_f90_kind), intent(out) :: asymp
+    end subroutine xc_f90_gga_ak13_get_asymptotic
+  end interface
+
+  !----------------------------------------------------------------
+  interface
+    subroutine xc_f90_hyb_exx_coef(p, coef)
       use xc_f90_types_m
       type(xc_f90_pointer_t), intent(in) :: p
+      real(xc_f90_kind), intent(out) :: coef
+    end subroutine xc_f90_hyb_exx_coef
+
+    subroutine xc_f90_hyb_cam_coef(p, omega, alpha, beta)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      real(xc_f90_kind), intent(out) :: omega, alpha, beta
+    end subroutine xc_f90_hyb_cam_coef
+  end interface
+
+
+  !----------------------------------------------------------------
+  interface
+    subroutine xc_f90_hyb_gga_xc_hse_set_par(p, beta, omega)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      real(xc_f90_kind), intent(in) :: beta ! mixing
       real(xc_f90_kind), intent(in) :: omega ! range separation
     end subroutine xc_f90_hyb_gga_xc_hse_set_par
+
+    subroutine xc_f90_hyb_gga_xc_pbeh_set_par(p, alpha)
+      use xc_f90_types_m
+      type(xc_f90_pointer_t), intent(in) :: p
+      real(xc_f90_kind), intent(in) :: alpha ! mixing
+    end subroutine xc_f90_hyb_gga_xc_pbeh_set_par
   end interface
 
 
