@@ -9,7 +9,7 @@
 subroutine mixpack(tpack,n,v)
 ! !USES:
 use modmain
-use modldapu
+use moddftu
 ! !INPUT/OUTPUT PARAMETERS:
 !   tpack : .true. for packing, .false. for unpacking (in,logical)
 !   n     : total number of real values stored (out,integer)
@@ -36,20 +36,20 @@ call rfpack(tpack,n,nrmt,nrmtinr,nrmtmax,vsmt,vsir,v)
 do idm=1,ndmag
   call rfpack(tpack,n,nrcmt,nrcmtinr,nrcmtmax,bsmt(:,:,:,idm),bsir(:,idm),v)
 end do
-! pack the LDA+U potential if required
-if (ldapu.ne.0) then
+! pack the DFT+U potential if required
+if (tvmatmt) then
   do ias=1,natmtot
     do ispn=1,nspinor
       do jspn=1,nspinor
-        do lm1=1,lmmaxlu
-          do lm2=1,lmmaxlu
+        do lm1=1,lmmaxdm
+          do lm2=1,lmmaxdm
             n=n+1
             if (tpack) then
-              v(n)=dble(vmatlu(lm1,lm2,ispn,jspn,ias))
+              v(n)=dble(vmatmt(lm1,ispn,lm2,jspn,ias))
               n=n+1
-              v(n)=aimag(vmatlu(lm1,lm2,ispn,jspn,ias))
+              v(n)=aimag(vmatmt(lm1,ispn,lm2,jspn,ias))
             else
-              vmatlu(lm1,lm2,ispn,jspn,ias)=cmplx(v(n),v(n+1),8)
+              vmatmt(lm1,ispn,lm2,jspn,ias)=cmplx(v(n),v(n+1),8)
               n=n+1
             end if
           end do
