@@ -19,12 +19,13 @@ integer natoms0(maxspecies)
 integer natmtot0
 real(8) atposl0(3,maxatoms,maxspecies)
 real(8) atposc0(3,maxatoms,maxspecies)
+real(8) rmtdelta0
 integer ngridg0(3),ngtot0
-logical spinpol0,spinorb0
+logical spinpol0,spinorb0,cmagz0
 real(8) bfieldc00(3)
 real(8) bfcmt00(3,maxatoms,maxspecies)
 real(8) reducebf0
-integer fixspin0
+integer fsmtype0
 real(8) momfix0(3)
 real(8) mommtfix0(3,maxatoms,maxspecies)
 logical tforce0
@@ -32,6 +33,8 @@ logical autokpt0
 integer ngridk0(3)
 real(8) vkloff0(3)
 logical ptnucl0
+logical ffdamp0
+real(8) fracinr0
 
 end module
 
