@@ -9,14 +9,14 @@
 subroutine readinput
 ! !USES:
 use modmain
-use modldapu
+use moddftu
 use modrdm
 use modphonon
-use modmpi
 use modtest
 use modrandom
 use modscdft
 use modpw
+use modtddft
 use modvars
 ! !DESCRIPTION:
 !   Reads in the input parameters from the file {\tt elk.in}. Also sets default
@@ -29,11 +29,13 @@ use modvars
 implicit none
 ! local variables
 logical nosym,highq
-integer is,js,ia,ias
-integer i,j,k,l,iv,iostat
+integer is,ia,ias,iostat
+integer i,j,k,l,n,p
 real(8) sc,sc1,sc2,sc3
-real(8) solscf,v(3),t1
-character(256) block,str
+real(8) solscf,zn,a,b
+real(8) axang(4),rot(3,3)
+real(8) v1(3),v2(3),t1
+character(256) block,symb,str
 
 !------------------------!
 !     default values     !
@@ -54,7 +56,7 @@ tshift=.true.
 ngridk(:)=1
 vkloff(:)=0.d0
 autokpt=.false.
-radkpt=40.d0
+radkpt=30.d0
 reducek=1
 ngridq(:)=1
 reduceq=1
@@ -62,9 +64,9 @@ rgkmax=7.d0
 gmaxvr=12.d0
 lmaxapw=8
 lmaxvr=7
-lmaxmat=5
+lmaxmat=6
 lmaxinr=3
-fracinr=0.2d0
+fracinr=0.1d0
 trhonorm=.true.
 xctype(1)=3
 xctype(2)=0
@@ -87,8 +89,8 @@ broydpm(1)=0.4d0
 broydpm(2)=0.15d0
 epspot=1.d-6
 epsengy=1.d-4
-epsforce=5.d-4
-epsstress=5.d-3
+epsforce=5.d-3
+epsstress=1.d-3
 molecule=.false.
 nspecies=0
 natoms(:)=0
@@ -126,10 +128,10 @@ spinorb=.false.
 socscf=1.d0
 maxatpstp=200
 tau0atp=0.25d0
-deltast=0.01d0
+deltast=0.005d0
 latvopt=0
-maxlatvstp=20
-tau0latv=0.01d0
+maxlatvstp=30
+tau0latv=0.1d0
 lradstp=4
 chgexs=0.d0
 scissor=0.d0
@@ -144,7 +146,7 @@ dlefe=-0.1d0
 bfieldc0(:)=0.d0
 efieldc(:)=0.d0
 afieldc(:)=0.d0
-fixspin=0
+fsmtype=0
 momfix(:)=0.d0
 mommtfix(:,:,:)=0.d0
 taufsm=0.01d0
@@ -175,17 +177,17 @@ ssdph=.true.
 vqlss(:)=0.d0
 nwrite=0
 tevecsv=.false.
-ldapu=0
-inptypelu=1
-llu(:)=-1
-ujlu(:,:)=0.d0
-flu(:,:)=0.d0
-elu(:,:)=0.d0
-lambdalu(:)=0.d0
-ulufix(:)=0.d0
-lambdalu0(:)=0.d0
-tmomlu=.false.
-readalu=.false.
+dftu=0
+inpdftu=1
+ndftu=0
+ujdu(:,:)=0.d0
+fdu(:,:)=0.d0
+edu(:,:)=0.d0
+lambdadu(:)=0.d0
+udufix(:)=0.d0
+lambdadu0(:)=0.d0
+tmwrite=.false.
+readadu=.false.
 rdmxctype=2
 rdmmaxscl=2
 maxitn=200
@@ -197,15 +199,17 @@ rdmbeta=0.25d0
 rdmtemp=0.d0
 reducebf=1.d0
 ptnucl=.true.
-tseqr=.true.
-tseqit=.false.
-nseqit=30
+tefvr=.true.
+tefvit=.false.
+minitefv=6
+maxitefv=20
+befvit=0.25d0
+epsefvit=1.d-5
 vecql(:)=0.d0
 mustar=0.15d0
 sqados(1:2)=0.d0
 sqados(3)=1.d0
 test=.false.
-frozencr=.false.
 spincore=.false.
 solscf=1.d0
 emaxelnes=-1.2d0
@@ -247,10 +251,22 @@ lorbcnd=.false.
 lorbordc=3
 nrmtscf=1
 lmaxdos=3
-epsph=0.01d0
+epsph=0.005d0
 msmooth=0
-npmae=4
+npmae0=-1
 wrtvars=.false.
+ftmtype=0
+ntmfix=0
+tauftm=0.5d0
+ftmstep=1
+cmagz=.false.
+axang(:)=0.d0
+ncgga=.false.
+tstime=5.d0
+dtimes=0.01d0
+npulse=0
+ntwrite=10
+ffdamp=.false.
 
 !--------------------------!
 !     read from elk.in     !
@@ -291,12 +307,30 @@ case('tasks')
   end do
   write(*,*)
   write(*,'("Error(readinput): too many tasks")')
+  write(*,'("Adjust maxtasks in modmain and recompile code")')
   write(*,*)
   stop
 case('species')
-  if (mp_mpi) call genspecies(50)
-! synchronise MPI processes
-  call mpi_barrier(mpi_comm_world,ierror)
+! generate a species file
+  call genspecies(50)
+case('fspecies')
+! generate fractional species files
+  do is=1,maxspecies
+    read(50,'(A256)',err=20) str
+    if (trim(str).eq.'') goto 10
+    read(str,*,iostat=iostat) zn,symb
+    if (zn.gt.-1.d0+epsocc) then
+      write(*,*)
+      write(*,'("Error(readinput): fractional nuclear Z > -1 : ",G18.10)') zn
+      write(*,*)
+      stop
+    end if
+    call genfspecies(zn,symb)
+  end do
+  write(*,*)
+  write(*,'("Error(readinput): too many fractional nucleus species")')
+  write(*,*)
+  stop
 case('avec')
   read(50,*,err=20) avec(:,1)
   read(50,*,err=20) avec(:,2)
@@ -590,8 +624,8 @@ case('plot1d')
   end if
   if (allocated(vvlp1d)) deallocate(vvlp1d)
   allocate(vvlp1d(3,nvp1d))
-  do iv=1,nvp1d
-    read(50,*,err=20) vvlp1d(:,iv)
+  do i=1,nvp1d
+    read(50,*,err=20) vvlp1d(:,i)
   end do
 case('plot2d')
   read(50,*,err=20) vclp2d(:,1)
@@ -770,8 +804,8 @@ case('efieldc')
   read(50,*,err=20) efieldc
 case('afieldc')
   read(50,*,err=20) afieldc
-case('fixspin')
-  read(50,*,err=20) fixspin
+case('fsmtype','fixspin')
+  read(50,*,err=20) fsmtype
 case('momfix')
   read(50,*,err=20) momfix
 case('mommtfix')
@@ -932,48 +966,78 @@ case('nwrite')
   read(50,*,err=20) nwrite
 case('tevecsv')
   read(50,*,err=20) tevecsv
-case('lda+u')
-  read(50,*,err=20) ldapu,inptypelu
-  do is=1,maxspecies
+case('DFT+U','dft+u','lda+u')
+  read(50,*,err=20) dftu,inpdftu
+  do i=1,maxdftu
     read(50,'(A256)',err=20) str
-    if (trim(str).eq.'') goto 10
-    if (inptypelu.eq.1) then
-      read(str,*,iostat=iostat) js,l,ujlu(1:2,js)
-    else if (inptypelu.eq.2) then
-      read(str,*,iostat=iostat) js,l,(flu(k,js),k=0,2*l,2)
-    else if (inptypelu.eq.3) then
-      read(str,*,iostat=iostat) js,l,(elu(k,js),k=0,l)
-    else if (inptypelu.eq.4) then
-      read(str,*,iostat=iostat) js,l,lambdalu(js)
-    else if (inptypelu.eq.5) then
-      read(str,*,iostat=iostat) js,l,ulufix(js)
+    if (trim(str).eq.'') then
+      ndftu=i-1
+      goto 10
     end if
+    select case(inpdftu)
+    case(1)
+      read(str,*,iostat=iostat) is,l,ujdu(1:2,i)
+    case(2)
+      read(str,*,iostat=iostat) is,l,(fdu(k,i),k=0,2*l,2)
+    case(3)
+      read(str,*,iostat=iostat) is,l,(edu(k,i),k=0,l)
+    case(4)
+      read(str,*,iostat=iostat) is,l,lambdadu(i)
+    case(5)
+      read(str,*,iostat=iostat) is,l,udufix(i)
+    case default
+      write(*,*)
+      write(*,'("Error(readinput): invalid inpdftu : ",I8)') inpdftu
+      write(*,*)
+      stop
+    end select
     if (iostat.ne.0) then
       write(*,*)
-      write(*,'("Error(readinput): error reading LDA+U parameters")')
-      write(*,'("(blank line required after lda+u block)")')
+      write(*,'("Error(readinput): error reading DFT+U parameters")')
+      write(*,'("(blank line required after dft+u block)")')
       write(*,*)
       stop
     end if
-    if ((js.le.0).or.(js.ge.maxspecies)) then
+    if ((is.le.0).or.(is.ge.maxspecies)) then
       write(*,*)
-      write(*,'("Error(readinput): invalid species number in lda+u block : ", &
-       &I8)') js
+      write(*,'("Error(readinput): invalid species number in dft+u block : ", &
+       &I8)') is
       write(*,*)
       stop
     end if
-    if (l.gt.lmaxlu) then
+    if (l.lt.0) then
       write(*,*)
-      write(*,'("Error(readinput): l > lmaxlu in lda+u block : ",2I8)') l,lmaxlu
+      write(*,'("Error(readinput): l < 0 in dft+u block : ",I8)') l
       write(*,*)
       stop
     end if
-    llu(js)=l
+    if (l.gt.lmaxdm) then
+      write(*,*)
+      write(*,'("Error(readinput): l > lmaxdm in dft+u block : ",2I8)') l,lmaxdm
+      write(*,*)
+      stop
+    end if
+! check for repeated entries
+    do j=1,i-1
+      if ((is.eq.idftu(1,j)).and.(l.eq.idftu(2,j))) then
+        write(*,*)
+        write(*,'("Error(readinput): repeated entry in DFT+U block")')
+        write(*,*)
+        stop
+      end if
+    end do
+    idftu(1,i)=is
+    idftu(2,i)=l
   end do
-case('tmomlu')
-  read(50,*,err=20) tmomlu
-case('readalu')
-  read(50,*,err=20) readalu
+  write(*,*)
+  write(*,'("Error(readinput): too many DFT+U entries")')
+  write(*,'("Adjust maxdftu in modmain and recompile code")')
+  write(*,*)
+  stop
+case('tmwrite','tmomlu')
+  read(50,*,err=20) tmwrite
+case('readadu','readalu')
+  read(50,*,err=20) readadu
 case('rdmxctype')
   read(50,*,err=20) rdmxctype
 case('rdmmaxscl')
@@ -1035,26 +1099,54 @@ case('rdmtemp')
   end if
 case('reducebf')
   read(50,*,err=20) reducebf
-  if ((reducebf.lt.0.d0).or.(reducebf.gt.1.d0)) then
+  if ((reducebf.lt.0.49d0).or.(reducebf.gt.1.d0)) then
     write(*,*)
-    write(*,'("Error(readinput): reducebf not in [0,1] : ",G18.10)') reducebf
+    write(*,'("Error(readinput): reducebf not in [0.5,1] : ",G18.10)') reducebf
     write(*,*)
     stop
   end if
 case('ptnucl')
   read(50,*,err=20) ptnucl
-case('tseqr')
-  read(50,*,err=20) tseqr
-case('tseqit')
-  read(50,*,err=20) tseqit
-case('nseqit')
-  read(50,*,err=20) nseqit
-  if (nseqit.lt.1) then
+case('tefvr','tseqr')
+  read(50,*,err=20) tefvr
+case('tefvit','tseqit')
+  read(50,*,err=20) tefvit
+case('minitefv','minseqit')
+  read(50,*,err=20) minitefv
+  if (minitefv.lt.1) then
     write(*,*)
-    write(*,'("Error(readinput): nseqit < 1 : ",I8)') nseqit
+    write(*,'("Error(readinput): minitefv < 1 : ",I8)') minitefv
     write(*,*)
     stop
   end if
+case('maxitefv','maxseqit')
+  read(50,*,err=20) maxitefv
+  if (maxitefv.lt.1) then
+    write(*,*)
+    write(*,'("Error(readinput): maxitefv < 1 : ",I8)') maxitefv
+    write(*,*)
+    stop
+  end if
+case('befvit','bseqit')
+  read(50,*,err=20) befvit
+  if (befvit.le.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): befvit <= 0 : ",G18.10)') befvit
+    write(*,*)
+    stop
+  end if
+case('epsefvit','epsseqit')
+  read(50,*,err=20) epsefvit
+  if (epsefvit.lt.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): epsefvit < 0 : ",G18.10)') epsefvit
+    write(*,*)
+    stop
+  end if
+case('nseqit')
+  read(50,*,err=20)
+  write(*,*)
+  write(*,'("Info(readinput): variable ''nseqit'' is no longer used")')
 case('tauseq')
   read(50,*,err=20)
   write(*,*)
@@ -1068,7 +1160,8 @@ case('sqados')
 case('test')
   read(50,*,err=20) test
 case('frozencr')
-  read(50,*,err=20) frozencr
+  write(*,*)
+  write(*,'("Info(readinput): variable ''frozencr'' is no longer used")')
 case('spincore')
   read(50,*,err=20) spincore
 case('solscf')
@@ -1245,12 +1338,13 @@ case('highq')
     gmaxvr=16.d0
     lmaxapw=10
     lmaxvr=8
-    lmaxmat=7
-    radkpt=60.d0
+    lmaxmat=8
+    lradstp=2
+    fracinr=0.05d0
+    radkpt=50.d0
     autokpt=.true.
     vkloff(:)=0.d0
     nempty0=10.d0
-    lradstp=2
     epspot=1.d-7
     epsengy=1.d-5
     epsforce=1.d-4
@@ -1322,15 +1416,118 @@ case('msmooth')
     stop
   end if
 case('npmae')
-  read(50,*,err=20) npmae
-  if (npmae.le.1) then
+  read(50,*,err=20) npmae0
+case('wrtvars')
+  read(50,*,err=20) wrtvars
+case('ftmtype')
+  read(50,*,err=20) ftmtype
+case('tmomfix')
+  read(50,*,err=20) ntmfix
+  if (ntmfix.le.0) then
     write(*,*)
-    write(*,'("Error(readinput): npmae <= 1 : ",I8)') npmae
+    write(*,'("Error(readinput): ntmfix <= 0 : ",I8)') ntmfix
     write(*,*)
     stop
   end if
-case('wrtvars')
-  read(50,*,err=20) wrtvars
+  if (allocated(itmfix)) deallocate(itmfix)
+  allocate(itmfix(8,ntmfix))
+  if (allocated(tmfix)) deallocate(tmfix)
+  allocate(tmfix(ntmfix))
+  if (allocated(rtmfix)) deallocate(rtmfix)
+  allocate(rtmfix(3,3,2,ntmfix))
+  do i=1,ntmfix
+    read(50,*,err=20) is,ia,l,n
+    if ((is.le.0).or.(ia.le.0).or.(l.lt.0).or.((n.ne.2).and.(n.ne.3))) then
+      write(*,*)
+      write(*,'("Error(readinput): invalid is, ia, l or n in tmomfix block : ",&
+       &4I8)') is,ia,l,n
+      write(*,*)
+      stop
+    end if
+    itmfix(1,i)=is
+    itmfix(2,i)=ia
+    itmfix(3,i)=l
+    itmfix(4,i)=n
+! read k, p, x, y for the 2-index tensor or k, p, r, t for the 3-index tensor
+    read(50,*,err=20) itmfix(5:8,i)
+! read tensor component
+    read(50,*,err=20) a,b
+    tmfix(i)=cmplx(a,b,8)
+! read parity and Euler angles of spatial and spin rotation matrices
+    read(50,'(A256)',err=20) str
+    str=trim(str)//' 0.0 0.0 0.0'
+    read(str,*,err=20) p,v1(:),v2(:)
+    if (abs(p).ne.1) then
+      write(*,*)
+      write(*,'("Error(readinput): parity should be -1 or 1 in tmomfix &
+       &block : ",I8)') p
+      write(*,*)
+      stop
+    end if
+! convert Euler angles from degrees to radians
+    v1(:)=v1(:)*pi/180.d0
+    v2(:)=v2(:)*pi/180.d0
+! compute the spatial and spin 3x3 rotation matrices from the Euler angles
+    call eulerrot(v1,rtmfix(:,:,1,i))
+    call eulerrot(v2,rtmfix(:,:,2,i))
+! multiply the spatial rotation matrix by the parity
+    rtmfix(:,:,1,i)=dble(p)*rtmfix(:,:,1,i)
+  end do
+case('tauftm')
+  read(50,*,err=20) tauftm
+  if (tauftm.lt.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): tauftm < 0 : ",G18.10)') tauftm
+    write(*,*)
+    stop
+  end if
+case('ftmstep')
+  read(50,*,err=20) ftmstep
+  if (ftmstep.lt.1) then
+    write(*,*)
+    write(*,'("Error(readinput): ftmstep < 1 : ",I8)') ftmstep
+    write(*,*)
+    stop
+  end if
+case('cmagz','forcecmag')
+  read(50,*,err=20) cmagz
+case('rotavec')
+  read(50,*,err=20) axang(:)
+case('tstime')
+  read(50,*,err=20) tstime
+  if (tstime.lt.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): tstime <= 0 : ",G18.10)') tstime
+    write(*,*)
+    stop
+  end if
+case('dtimes')
+  read(50,*,err=20) dtimes
+  if (dtimes.le.0.d0) then
+    write(*,*)
+    write(*,'("Error(readinput): dtimes <= 0 : ",G18.10)') dtimes
+    write(*,*)
+    stop
+  end if
+case('pulse')
+  read(50,*,err=20) npulse
+  if (npulse.lt.1) then
+    write(*,*)
+    write(*,'("Error(readinput): npulse < 1 : ",I8)') npulse
+    write(*,*)
+    stop
+  end if
+  if (allocated(pulse)) deallocate(pulse)
+  allocate(pulse(7,npulse))
+  do i=1,npulse
+    read(50,*,err=20) pulse(:,i)
+  end do
+case('ncgga')
+  read(50,*,err=20) ncgga
+case('ntwrite')
+  read(50,*,err=20) ntwrite
+case('ffdamp')
+  read(50,*,err=20) ffdamp
 case('')
   goto 10
 case default
@@ -1351,11 +1548,20 @@ stop
 close(50)
 ! scale the speed of light
 solsc=sol*solscf
-! scale the lattice vectors (scaling not referenced again in code)
+! scale and rotate the lattice vectors (not referenced again in code)
 avec(:,1)=sc1*avec(:,1)
 avec(:,2)=sc2*avec(:,2)
 avec(:,3)=sc3*avec(:,3)
 avec(:,:)=sc*avec(:,:)
+t1=axang(4)
+if (t1.ne.0.d0) then
+  t1=t1*pi/180.d0
+  call axangrot(axang(:),t1,rot)
+  do i=1,3
+    v1(:)=avec(:,i)
+    call r3mv(rot,v1,avec(:,i))
+  end do
+end if
 ! randomise lattice vectors if required
 if (rndavec.gt.0.d0) then
   do i=1,3
@@ -1371,8 +1577,8 @@ if (molecule) then
   call r3minv(avec,ainv)
   do is=1,nspecies
     do ia=1,natoms(is)
-      call r3mv(ainv,atposl(:,ia,is),v)
-      atposl(:,ia,is)=v(:)
+      call r3mv(ainv,atposl(:,ia,is),v1)
+      atposl(:,ia,is)=v1(:)
     end do
   end do
 end if
@@ -1381,12 +1587,12 @@ if (rndatposc.gt.0.d0) then
   call r3minv(avec,ainv)
   do is=1,nspecies
     do ia=1,natoms(is)
-      call r3mv(avec,atposl(:,ia,is),v)
+      call r3mv(avec,atposl(:,ia,is),v1)
       do i=1,3
         t1=rndatposc*(randomu()-0.5d0)
-        v(i)=v(i)+t1
+        v1(i)=v1(i)+t1
       end do
-      call r3mv(ainv,v,atposl(:,ia,is))
+      call r3mv(ainv,v1,atposl(:,ia,is))
     end do
   end do
 end if
