@@ -3,7 +3,7 @@
 ! This file is distributed under the terms of the GNU General Public License.
 ! See the file COPYING for license details.
 
-subroutine rfpack(tpack,n,nr,nri,ld,rfmt,rfir,nu)
+subroutine rfpack(tpack,n,nr,nri,ld,rfmt,rfir,v)
 use modmain
 implicit none
 ! arguments
@@ -13,49 +13,39 @@ integer, intent(in) :: nr(nspecies),nri(nspecies)
 integer, intent(in) :: ld
 real(8), intent(inout) :: rfmt(lmmaxvr,ld,natmtot)
 real(8), intent(inout) :: rfir(ngtot)
-real(8), intent(out) :: nu(*)
+real(8), intent(out) :: v(*)
 ! local variables
 integer is,ias,ir,lmmax,lm
 if (tpack) then
 ! pack the function
   do ias=1,natmtot
     is=idxis(ias)
+    lmmax=lmmaxinr
     do ir=1,nr(is)
-      if (ir.le.nri(is)) then
-        lmmax=lmmaxinr
-      else
-        lmmax=lmmaxvr
-      end if
       do lm=1,lmmax
         n=n+1
-        nu(n)=rfmt(lm,ir,ias)
+        v(n)=rfmt(lm,ir,ias)
       end do
+      if (ir.eq.nri(is)) lmmax=lmmaxvr
     end do
   end do
-  do ir=1,ngtot
-    n=n+1
-    nu(n)=rfir(ir)
-  end do
+  call dcopy(ngtot,rfir,1,v(n+1),1)
+  n=n+ngtot
 else
 ! unpack the function
   do ias=1,natmtot
     is=idxis(ias)
+    lmmax=lmmaxinr
     do ir=1,nr(is)
-      if (ir.le.nri(is)) then
-        lmmax=lmmaxinr
-      else
-        lmmax=lmmaxvr
-      end if
       do lm=1,lmmax
         n=n+1
-        rfmt(lm,ir,ias)=nu(n)
+        rfmt(lm,ir,ias)=v(n)
       end do
+      if (ir.eq.nri(is)) lmmax=lmmaxvr
     end do
   end do
-  do ir=1,ngtot
-    n=n+1
-    rfir(ir)=nu(n)
-  end do
+  call dcopy(ngtot,v(n+1),1,rfir,1)
+  n=n+ngtot
 end if
 return
 end subroutine
