@@ -7,7 +7,7 @@ subroutine wfcrplot
 use modmain
 implicit none
 ! local variables
-integer is,ia,ias,ir,ist
+integer ist,is,ia,ias,ir
 character(256) fname
 ! initialise universal variables
 call init0
