@@ -12,19 +12,16 @@ integer ispn,is,ia,ias
 real(8) xl(3),xs(3),t1
 ! allocatable arrays
 complex(8), allocatable :: apwalm(:,:,:,:,:)
-complex(8), allocatable :: evecfv(:,:,:)
-complex(8), allocatable :: evecsv(:,:)
-complex(8), allocatable :: dmat1(:,:,:,:,:)
-complex(8), allocatable :: dmat2(:,:,:,:,:)
+complex(8), allocatable :: evecfv(:,:,:),evecsv(:,:)
+complex(8), allocatable :: dmat1(:,:,:,:,:),dmat2(:,:,:,:,:)
 complex(8), allocatable :: zlflm(:,:)
 ! initialise universal variables
 call init0
 call init1
 allocate(apwalm(ngkmax,apwordmax,lmmaxapw,natmtot,nspnfv))
-allocate(evecfv(nmatmax,nstfv,nspnfv))
-allocate(evecsv(nstsv,nstsv))
-allocate(dmat1(lmmaxvr,lmmaxvr,nspinor,nspinor,natmtot))
-allocate(dmat2(lmmaxvr,lmmaxvr,nspinor,nspinor,nstsv))
+allocate(evecfv(nmatmax,nstfv,nspnfv),evecsv(nstsv,nstsv))
+allocate(dmat1(lmmaxvr,nspinor,lmmaxvr,nspinor,natmtot))
+allocate(dmat2(lmmaxvr,nspinor,lmmaxvr,nspinor,nstsv))
 allocate(zlflm(lmmaxvr,3))
 ! read density and potentials from file
 call readstate
@@ -77,7 +74,7 @@ if (task.eq.15) then
       xl(:)=0.d0
       do ispn=1,nspinor
         do lm=1,lmmaxvr
-          call lopzflm(lmaxvr,dmat1(:,lm,ispn,ispn,ias),lmmaxvr,zlflm)
+          call lopzflm(lmaxvr,dmat1(:,ispn,lm,ispn,ias),lmmaxvr,zlflm)
           xl(:)=xl(:)+dble(zlflm(lm,:))
         end do
       end do
@@ -85,9 +82,9 @@ if (task.eq.15) then
       xs(:)=0.d0
       if (spinpol) then
         do lm=1,lmmaxvr
-          xs(1)=xs(1)+dble(dmat1(lm,lm,2,1,ias)+dmat1(lm,lm,1,2,ias))
-          xs(2)=xs(2)+dble(-zi*dmat1(lm,lm,2,1,ias)+zi*dmat1(lm,lm,1,2,ias))
-          xs(3)=xs(3)+dble(dmat1(lm,lm,1,1,ias)-dmat1(lm,lm,2,2,ias))
+          xs(1)=xs(1)+dble(dmat1(lm,2,lm,1,ias)+dmat1(lm,1,lm,2,ias))
+          xs(2)=xs(2)+dble(-zi*dmat1(lm,2,lm,1,ias)+zi*dmat1(lm,1,lm,2,ias))
+          xs(3)=xs(3)+dble(dmat1(lm,1,lm,1,ias)-dmat1(lm,2,lm,2,ias))
         end do
       end if
 ! S = 1/2 sigma
@@ -143,7 +140,7 @@ else
         xl(:)=0.d0
         do ispn=1,nspinor
           do lm=1,lmmaxvr
-            call lopzflm(lmaxvr,dmat2(:,lm,ispn,ispn,ist),lmmaxvr,zlflm)
+            call lopzflm(lmaxvr,dmat2(:,ispn,lm,ispn,ist),lmmaxvr,zlflm)
             xl(:)=xl(:)+dble(zlflm(lm,:))
           end do
         end do
@@ -151,9 +148,9 @@ else
         xs(:)=0.d0
         if (spinpol) then
           do lm=1,lmmaxvr
-            xs(1)=xs(1)+dble(dmat2(lm,lm,2,1,ist)+dmat2(lm,lm,1,2,ist))
-            xs(2)=xs(2)+dble(-zi*dmat2(lm,lm,2,1,ist)+zi*dmat2(lm,lm,1,2,ist))
-            xs(3)=xs(3)+dble(dmat2(lm,lm,1,1,ist)-dmat2(lm,lm,2,2,ist))
+            xs(1)=xs(1)+dble(dmat2(lm,2,lm,1,ist)+dmat2(lm,1,lm,2,ist))
+            xs(2)=xs(2)+dble(-zi*dmat2(lm,2,lm,1,ist)+zi*dmat2(lm,1,lm,2,ist))
+            xs(3)=xs(3)+dble(dmat2(lm,1,lm,1,ist)-dmat2(lm,2,lm,2,ist))
           end do
         else
           xs(3)=1.d0
