@@ -6,15 +6,13 @@
 !BOP
 ! !ROUTINE: ylmrot
 ! !INTERFACE:
-subroutine ylmrot(p,alpha,beta,gamma,lmax,ld,d)
+subroutine ylmrot(p,ang,lmax,ld,d)
 ! !INPUT/OUTPUT PARAMETERS:
-!   p     : if p=-1 then the rotation matrix is improper (in,integer)
-!   alpha : first Euler angle (in,real)
-!   beta  : second Euler angle (in,real)
-!   gamma : third Euler angle (in,real)
-!   lmax  : maximum angular momentum (in,integer)
-!   ld    : leading dimension (in,integer)
-!   d     : complex spherical harmonic rotation matrix (out,complex(ld,*))
+!   p    : if p=-1 then the rotation matrix is improper (in,integer)
+!   ang  : Euler angles; alpha, beta, gamma (in,real(3))
+!   lmax : maximum angular momentum (in,integer)
+!   ld   : leading dimension (in,integer)
+!   d    : complex spherical harmonic rotation matrix (out,complex(ld,*))
 ! !DESCRIPTION:
 !   Returns the rotation matrix in the basis of complex spherical harmonics
 !   given the three Euler angles, $(\alpha,\beta,\gamma)$, and the parity, $p$,
@@ -24,7 +22,7 @@ subroutine ylmrot(p,alpha,beta,gamma,lmax,ld,d)
 !   where $d$ is the rotation matrix about the $y$-axis. For improper rotations,
 !   i.e. those which are a combination of a rotation and inversion, $D$ is
 !   modified with $D^l_{m_1m_2}\rightarrow(-1)^l D^l_{m_1m_2}$. See the routines
-!   {\tt euler} and {\tt ylmroty}.
+!   {\tt roteuler} and {\tt ylmroty}.
 !
 ! !REVISION HISTORY:
 !   Created December 2008 (JKD)
@@ -33,9 +31,7 @@ subroutine ylmrot(p,alpha,beta,gamma,lmax,ld,d)
 implicit none
 ! arguments
 integer, intent(in) :: p
-real(8), intent(in) :: alpha
-real(8), intent(in) :: beta
-real(8), intent(in) :: gamma
+real(8), intent(in) :: ang(3)
 integer, intent(in) :: lmax
 integer, intent(in) :: ld
 complex(8), intent(out) :: d(ld,*)
@@ -53,7 +49,7 @@ end if
 lmmax=(lmax+1)**2
 allocate(dy(lmmax,lmmax))
 ! generate the rotation matrix about the y-axis
-call ylmroty(beta,lmax,lmmax,dy)
+call ylmroty(ang(2),lmax,lmmax,dy)
 ! rotation by alpha and gamma, as well as inversion if required
 lm1=0
 do l=0,lmax
@@ -62,7 +58,7 @@ do l=0,lmax
     lm2=l**2
     do m2=-l,l
       lm2=lm2+1
-      t1=-dble(m1)*alpha-dble(m2)*gamma
+      t1=-dble(m1)*ang(1)-dble(m2)*ang(3)
       d(lm1,lm2)=dy(lm1,lm2)*cmplx(cos(t1),sin(t1),8)
       if ((p.eq.-1).and.(mod(l,2).ne.0)) d(lm1,lm2)=-d(lm1,lm2)
     end do
