@@ -20,44 +20,33 @@ if (tpack) then
 ! pack the function
   do ias=1,natmtot
     is=idxis(ias)
+    lmmax=lmmaxinr
     do ir=1,nr(is)
-      if (ir.le.nri(is)) then
-        lmmax=lmmaxinr
-      else
-        lmmax=lmmaxvr
-      end if
       do lm=1,lmmax
         v(n+1)=dble(zfmt(lm,ir,ias))
         v(n+2)=aimag(zfmt(lm,ir,ias))
         n=n+2
       end do
+      if (ir.eq.nri(is)) lmmax=lmmaxvr
     end do
   end do
-  do ir=1,ngtot
-    v(n+1)=dble(zfir(ir))
-    v(n+2)=aimag(zfir(ir))
-    n=n+2
-  end do
+  call dcopy(2*ngtot,zfir,1,v(n+1),1)
+  n=n+2*ngtot
 else
 ! unpack the function
   do ias=1,natmtot
     is=idxis(ias)
+    lmmax=lmmaxinr
     do ir=1,nr(is)
-      if (ir.le.nri(is)) then
-        lmmax=lmmaxinr
-      else
-        lmmax=lmmaxvr
-      end if
       do lm=1,lmmax
         zfmt(lm,ir,ias)=cmplx(v(n+1),v(n+2),8)
         n=n+2
       end do
+      if (ir.eq.nri(is)) lmmax=lmmaxvr
     end do
   end do
-  do ir=1,ngtot
-    zfir(ir)=cmplx(v(n+1),v(n+2),8)
-    n=n+2
-  end do
+  call dcopy(2*ngtot,v(n+1),1,zfir,1)
+  n=n+2*ngtot
 end if
 return
 end subroutine
